# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vector_tile.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='vector_tile.proto',
  package='vector_tile',
  serialized_pb=_b('\n\x11vector_tile.proto\x12\x0bvector_tile\"\xa6\x08\n\x04Tile\x12\'\n\x06layers\x18\x03 \x03(\x0b\x32\x17.vector_tile.Tile.Layer\x1a\xa1\x01\n\x05Value\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\x01\x12\x11\n\tint_value\x18\x04 \x01(\x03\x12\x12\n\nuint_value\x18\x05 \x01(\x04\x12\x12\n\nsint_value\x18\x06 \x01(\x12\x12\x12\n\nbool_value\x18\x07 \x01(\x08*\x08\x08\x08\x10\x80\x80\x80\x80\x02\x1a;\n\x07Scaling\x12\x0e\n\x06offset\x18\x01 \x01(\x12\x12\x12\n\nmultiplier\x18\x02 \x01(\x01\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\x01\x1a\x8b\x02\n\x07\x46\x65\x61ture\x12\r\n\x02id\x18\x01 \x01(\x04:\x01\x30\x12\x10\n\x04tags\x18\x02 \x03(\rB\x02\x10\x01\x12\x31\n\x04type\x18\x03 \x01(\x0e\x32\x1a.vector_tile.Tile.GeomType:\x07UNKNOWN\x12\x14\n\x08geometry\x18\x04 \x03(\rB\x02\x10\x01\x12\x16\n\nattributes\x18\x05 \x03(\x04\x42\x02\x10\x01\x12 \n\x14geometric_attributes\x18\x06 \x03(\x04\x42\x02\x10\x01\x12\x15\n\televation\x18\x07 \x03(\x11\x42\x02\x10\x01\x12\x18\n\x0cspline_knots\x18\x08 \x03(\x04\x42\x02\x10\x01\x12\x18\n\rspline_degree\x18\t \x01(\r:\x01\x32\x12\x11\n\tstring_id\x18\n \x01(\t\x1a\xb1\x03\n\x05Layer\x12\x12\n\x07version\x18\x0f \x02(\r:\x01\x31\x12\x0c\n\x04name\x18\x01 \x02(\t\x12+\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x19.vector_tile.Tile.Feature\x12\x0c\n\x04keys\x18\x03 \x03(\t\x12\'\n\x06values\x18\x04 \x03(\x0b\x32\x17.vector_tile.Tile.Value\x12\x14\n\x06\x65xtent\x18\x05 \x01(\r:\x04\x34\x30\x39\x36\x12\x15\n\rstring_values\x18\x06 \x03(\t\x12\x18\n\x0c\x66loat_values\x18\x07 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rdouble_values\x18\x08 \x03(\x01\x42\x02\x10\x01\x12\x16\n\nint_values\x18\t \x03(\x06\x42\x02\x10\x01\x12\x34\n\x11\x65levation_scaling\x18\n \x01(\x0b\x32\x19.vector_tile.Tile.Scaling\x12\x35\n\x12\x61ttribute_scalings\x18\x0b \x03(\x0b\x32\x19.vector_tile.Tile.Scaling\x12\x0e\n\x06tile_x\x18\x0c \x01(\r\x12\x0e\n\x06tile_y\x18\r \x01(\r\x12\x11\n\ttile_zoom\x18\x0e \x01(\r*\x08\x08\x10\x10\x80\x80\x80\x80\x02\"K\n\x08GeomType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05POINT\x10\x01\x12\x0e\n\nLINESTRING\x10\x02\x12\x0b\n\x07POLYGON\x10\x03\x12\n\n\x06SPLINE\x10\x04*\x05\x08\x10\x10\x80@B\x02H\x03')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_TILE_GEOMTYPE = _descriptor.EnumDescriptor(
  name='GeomType',
  full_name='vector_tile.Tile.GeomType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POINT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINESTRING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLYGON', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPLINE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1015,
  serialized_end=1090,
)
_sym_db.RegisterEnumDescriptor(_TILE_GEOMTYPE)


_TILE_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='vector_tile.Tile.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='vector_tile.Tile.Value.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='vector_tile.Tile.Value.float_value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='vector_tile.Tile.Value.double_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='vector_tile.Tile.Value.int_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uint_value', full_name='vector_tile.Tile.Value.uint_value', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sint_value', full_name='vector_tile.Tile.Value.sint_value', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='vector_tile.Tile.Value.bool_value', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=True,
  extension_ranges=[(8, 536870912), ],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=246,
)

_TILE_SCALING = _descriptor.Descriptor(
  name='Scaling',
  full_name='vector_tile.Tile.Scaling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='vector_tile.Tile.Scaling.offset', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='multiplier', full_name='vector_tile.Tile.Scaling.multiplier', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='vector_tile.Tile.Scaling.base', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=307,
)

_TILE_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='vector_tile.Tile.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vector_tile.Tile.Feature.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='vector_tile.Tile.Feature.tags', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='type', full_name='vector_tile.Tile.Feature.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='vector_tile.Tile.Feature.geometry', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='vector_tile.Tile.Feature.attributes', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='geometric_attributes', full_name='vector_tile.Tile.Feature.geometric_attributes', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='vector_tile.Tile.Feature.elevation', index=6,
      number=7, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='spline_knots', full_name='vector_tile.Tile.Feature.spline_knots', index=7,
      number=8, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='spline_degree', full_name='vector_tile.Tile.Feature.spline_degree', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_id', full_name='vector_tile.Tile.Feature.string_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=577,
)

_TILE_LAYER = _descriptor.Descriptor(
  name='Layer',
  full_name='vector_tile.Tile.Layer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='vector_tile.Tile.Layer.version', index=0,
      number=15, type=13, cpp_type=3, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='vector_tile.Tile.Layer.name', index=1,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='features', full_name='vector_tile.Tile.Layer.features', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keys', full_name='vector_tile.Tile.Layer.keys', index=3,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='vector_tile.Tile.Layer.values', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extent', full_name='vector_tile.Tile.Layer.extent', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4096,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_values', full_name='vector_tile.Tile.Layer.string_values', index=6,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='float_values', full_name='vector_tile.Tile.Layer.float_values', index=7,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='double_values', full_name='vector_tile.Tile.Layer.double_values', index=8,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='int_values', full_name='vector_tile.Tile.Layer.int_values', index=9,
      number=9, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='elevation_scaling', full_name='vector_tile.Tile.Layer.elevation_scaling', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attribute_scalings', full_name='vector_tile.Tile.Layer.attribute_scalings', index=11,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tile_x', full_name='vector_tile.Tile.Layer.tile_x', index=12,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tile_y', full_name='vector_tile.Tile.Layer.tile_y', index=13,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tile_zoom', full_name='vector_tile.Tile.Layer.tile_zoom', index=14,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=True,
  extension_ranges=[(16, 536870912), ],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=1013,
)

_TILE = _descriptor.Descriptor(
  name='Tile',
  full_name='vector_tile.Tile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layers', full_name='vector_tile.Tile.layers', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TILE_VALUE, _TILE_SCALING, _TILE_FEATURE, _TILE_LAYER, ],
  enum_types=[
    _TILE_GEOMTYPE,
  ],
  options=None,
  is_extendable=True,
  extension_ranges=[(16, 8192), ],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=1097,
)

_TILE_VALUE.containing_type = _TILE
_TILE_SCALING.containing_type = _TILE
_TILE_FEATURE.fields_by_name['type'].enum_type = _TILE_GEOMTYPE
_TILE_FEATURE.containing_type = _TILE
_TILE_LAYER.fields_by_name['features'].message_type = _TILE_FEATURE
_TILE_LAYER.fields_by_name['values'].message_type = _TILE_VALUE
_TILE_LAYER.fields_by_name['elevation_scaling'].message_type = _TILE_SCALING
_TILE_LAYER.fields_by_name['attribute_scalings'].message_type = _TILE_SCALING
_TILE_LAYER.containing_type = _TILE
_TILE.fields_by_name['layers'].message_type = _TILE_LAYER
_TILE_GEOMTYPE.containing_type = _TILE
DESCRIPTOR.message_types_by_name['Tile'] = _TILE

Tile = _reflection.GeneratedProtocolMessageType('Tile', (_message.Message,), dict(

  Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
    DESCRIPTOR = _TILE_VALUE,
    __module__ = 'vector_tile_pb2'
    # @@protoc_insertion_point(class_scope:vector_tile.Tile.Value)
    ))
  ,

  Scaling = _reflection.GeneratedProtocolMessageType('Scaling', (_message.Message,), dict(
    DESCRIPTOR = _TILE_SCALING,
    __module__ = 'vector_tile_pb2'
    # @@protoc_insertion_point(class_scope:vector_tile.Tile.Scaling)
    ))
  ,

  Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), dict(
    DESCRIPTOR = _TILE_FEATURE,
    __module__ = 'vector_tile_pb2'
    # @@protoc_insertion_point(class_scope:vector_tile.Tile.Feature)
    ))
  ,

  Layer = _reflection.GeneratedProtocolMessageType('Layer', (_message.Message,), dict(
    DESCRIPTOR = _TILE_LAYER,
    __module__ = 'vector_tile_pb2'
    # @@protoc_insertion_point(class_scope:vector_tile.Tile.Layer)
    ))
  ,
  DESCRIPTOR = _TILE,
  __module__ = 'vector_tile_pb2'
  # @@protoc_insertion_point(class_scope:vector_tile.Tile)
  ))
_sym_db.RegisterMessage(Tile)
_sym_db.RegisterMessage(Tile.Value)
_sym_db.RegisterMessage(Tile.Scaling)
_sym_db.RegisterMessage(Tile.Feature)
_sym_db.RegisterMessage(Tile.Layer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\003'))
_TILE_FEATURE.fields_by_name['tags'].has_options = True
_TILE_FEATURE.fields_by_name['tags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_FEATURE.fields_by_name['geometry'].has_options = True
_TILE_FEATURE.fields_by_name['geometry']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_FEATURE.fields_by_name['attributes'].has_options = True
_TILE_FEATURE.fields_by_name['attributes']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_FEATURE.fields_by_name['geometric_attributes'].has_options = True
_TILE_FEATURE.fields_by_name['geometric_attributes']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_FEATURE.fields_by_name['elevation'].has_options = True
_TILE_FEATURE.fields_by_name['elevation']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_FEATURE.fields_by_name['spline_knots'].has_options = True
_TILE_FEATURE.fields_by_name['spline_knots']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_LAYER.fields_by_name['float_values'].has_options = True
_TILE_LAYER.fields_by_name['float_values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_LAYER.fields_by_name['double_values'].has_options = True
_TILE_LAYER.fields_by_name['double_values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TILE_LAYER.fields_by_name['int_values'].has_options = True
_TILE_LAYER.fields_by_name['int_values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



import numbers
import math


class LayerInfo:
    def __init__(self, name: str, zoom_level: str):
        self.name = name
        self.count = 0
        self.attributes = set()
        self.attributes_sample_values = {}
        self.attributes_types = {}
        self.attributes_numeric_domain = {}
        self.zoom_level = zoom_level

    def add_feature(self, attributes: dict):
        self.count += 1
        for key, value in attributes.items():
            if key not in self.attributes:
                self.attributes.add(key)
                self.attributes_sample_values[key] = set()
                self.attributes_types[key] = set()

            # populate attribute value
            attr_values: set = self.attributes_sample_values[key]
            if len(attr_values) < 100:
                if value not in attr_values:
                    attr_values.add(value)

            # populate attribute type
            attr_types: set = self.attributes_types[key]
            attr_type = type(value).__name__
            if attr_type not in attr_types:
                attr_types.add(attr_type)

            # get attribute numeric domain
            if isinstance(value, numbers.Number):
                if key not in self.attributes_numeric_domain:
                    self.attributes_numeric_domain[key] = [math.inf, -math.inf]

                attr_domain = self.attributes_numeric_domain[key]
                if value < attr_domain[0]:
                    attr_domain[0] = value
                if value > attr_domain[1]:
                    attr_domain[1] = value





from typing import List

from tileset_analyzer.entities.layer_info import LayerInfo


class TilesetInfo:
    def __init__(self):
        self.name: str = None
        self.scheme: str = None
        self.size: int = None
        self.location: str = None
        self.ds_type: str = None
        self.layer_info_items = None

    def set_name(self, name: str):
        self.name = name

    def set_scheme(self, scheme: str):
        self.scheme = scheme

    def set_size(self, size: int):
        self.size = size

    def set_location(self, location: str):
        self.location = location

    def set_ds_type(self, ds_type: str):
        self.ds_type = ds_type

    def set_layer_info(self, layer_info_items: List[LayerInfo]):
        self.layer_info_items = layer_info_items



from main import execute


if __name__ == "__main__":
    src_path = 'data/maptiler-osm-2017-07-03-v3.6.1-us_virginia.mbtiles'
    temp_folder = 'tileset_analyzer/static/data'
    scheme = 'TMS'
    actions = ['process', 'serve']
    execute(src_path, scheme, temp_folder, actions)



import abc
from collections import namedtuple
from sqlite3 import Connection
from typing import List
from tileset_analyzer.data_source.mbtiles.sqllite_utils import create_connection
from tileset_analyzer.data_source.tile_source import TileSource
from tileset_analyzer.entities.layer_info import LayerInfo
from tileset_analyzer.entities.layer_level_size import LayerLevelSize, TileItemSize
from tileset_analyzer.entities.level_size import LevelSize
from tileset_analyzer.entities.tile_item import TileItem
from tileset_analyzer.entities.tileset_analysis_result import LevelCount, TilesetAnalysisResult
from tileset_analyzer.data_source.mbtiles.sql_queries import SQL_COUNT_TILES, SQL_COUNT_TILES_BY_Z, \
    SQL_SUM_TILE_SIZES_BY_Z, SQL_MIN_TILE_SIZES_BY_Z, SQL_MAX_TILE_SIZES_BY_Z, SQL_AVG_TILE_SIZES_BY_Z, \
    SQL_LIST_TILE_SIZES_BY_Z, SQL_ALL_TILES
import pandas as pd
from tileset_analyzer.entities.tileset_info import TilesetInfo
import os
from pathlib import Path
import base64
from tileset_analyzer.readers.vector_tile.engine import VectorTile
import gzip
import multiprocessing
from multiprocessing.pool import ThreadPool as Pool
import sys

from tileset_analyzer.utilities.moniter import timeit


class MBTileSource(TileSource):

    def __init__(self, src_path: str, scheme: str):
        self.conn = create_connection(src_path)
        self.tiles_size_z_df = None
        self.src_path = src_path
        self.scheme = scheme

    def count_tiles(self) -> int:
        cur = self.conn.cursor()
        cur.execute(SQL_COUNT_TILES)
        count = cur.fetchone()[0]
        return count

    def count_tiles_by_z(self) -> List[LevelCount]:
        cur = self.conn.cursor()
        cur.execute(SQL_COUNT_TILES_BY_Z)
        rows = cur.fetchall()
        result: List[LevelCount] = []
        for row in rows:
            result.append(LevelCount(row[0], row[1]))
        return result

    def _get_agg_tile_size_z(self, agg_type: str) -> List[LevelSize]:
        sql = None
        if agg_type == 'SUM':
            sql = SQL_SUM_TILE_SIZES_BY_Z
        elif agg_type == 'MIN':
            sql = SQL_MIN_TILE_SIZES_BY_Z
        elif agg_type == 'MAX':
            sql = SQL_MAX_TILE_SIZES_BY_Z
        elif agg_type == 'AVG':
            sql = SQL_AVG_TILE_SIZES_BY_Z
        else:
            raise 'UNKNOWN AGG TYPE'

        cur = self.conn.cursor()
        cur.execute(sql)
        rows = cur.fetchall()
        result: List[LevelSize] = []
        for row in rows:
            result.append(LevelSize(row[0], row[1]))
        return result

    def _get_all_tiles(self) -> List[TileItem]:
        cur = self.conn.cursor()
        cur.execute(SQL_ALL_TILES)
        rows = cur.fetchall()
        result: List[LevelSize] = []
        for row in rows:
            result.append(TileItem(row[0], row[1], row[2], row[3]))
        return result

    def _set_tilesize_z_dataframe(self):
        query = SQL_LIST_TILE_SIZES_BY_Z
        cur = self.conn.cursor()
        self.tiles_size_z_df = pd.read_sql(query, self.conn)
        cur.close()

    def _clear_tilesize_z_dataframe(self):
        self.tiles_size_z_df = None

    def _get_agg_tile_size_percentiles_z(self, percentile_type: str) -> List[LevelSize]:
        quantile = None
        if percentile_type == '50p':
            quantile = 0.5
        elif percentile_type == '85p':
            quantile = 0.85
        elif percentile_type == '90p':
            quantile = 0.9
        elif percentile_type == '95p':
            quantile = 0.95
        elif percentile_type == '99p':
            quantile = 0.99
        else:
            raise 'UNKNOWN PERCENTILE TYPE'

        result_df = self.tiles_size_z_df.groupby('zoom_level').quantile(quantile)
        result: List[LevelSize] = []
        for row in result_df.itertuples():
            result.append(LevelSize(row[0], row[1]))
        return result

    def tiles_size_agg_min_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_z('MIN')

    def tiles_size_agg_max_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_z('MAX')

    def tiles_size_agg_avg_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_z('AVG')

    def tiles_size_agg_sum_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_z('SUM')

    def tiles_size_agg_50p_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_percentiles_z('50p')

    def tiles_size_agg_85p_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_percentiles_z('85p')

    def tiles_size_agg_90p_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_percentiles_z('90p')

    def tiles_size_agg_95p_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_percentiles_z('95p')

    def tiles_size_agg_99p_by_z(self) -> List[LevelSize]:
        return self._get_agg_tile_size_percentiles_z('99p')

    @timeit
    def tileset_info(self) -> TilesetInfo:
        tileset_info = TilesetInfo()
        tileset_info.set_name((self.src_path.split('/')[-1]).split('.')[0])
        tileset_info.set_size(os.stat(self.src_path).st_size)
        tileset_info.set_scheme(self.scheme)
        tileset_info.set_location(str(Path(self.src_path).parent.absolute()))
        tileset_info.set_ds_type('mbtiles')

        attr_info = {}
        tiles = self._get_all_tiles()

        def process_tile(tile):
            if tile.z not in attr_info:
                attr_info[tile.z] = {}

            zoom_level_info = attr_info[tile.z]

            data = gzip.decompress(tile.data)
            vt = VectorTile(data)
            for layer in vt.layers:
                if layer.name not in zoom_level_info:
                    zoom_level_info[layer.name] = LayerInfo(layer.name, tile.z)

                layer_info = zoom_level_info[layer.name]
                for feature in layer.features:
                    layer_info.add_feature(feature.attributes.get())

        with Pool(processes=multiprocessing.cpu_count()) as pool:
            pool.map(process_tile, tiles)

        # get all layer infos
        all_layers = []
        for zoom_level in sorted(attr_info.keys()):
            layer_dict = attr_info[zoom_level]
            for layer_name in sorted(layer_dict.keys()):
                layer = layer_dict[layer_name]
                all_layers.append(layer)
        tileset_info.set_layer_info(all_layers)
        return tileset_info

    @timeit
    def tiles_size_agg_sum_by_z_layer(self) -> List[LayerLevelSize]:
        all_tile_sizes: dict[str, List[TileItemSize]] = {}
        tiles = self._get_all_tiles()

        def normalize_tile_sizes(total: int, layers: dict[str, int]) -> dict[str, int]:
            final = {}
            layer_sum = sum([layer_size for layer_size in layers.values()])
            for layer_name, layer_size in layers.items():
                final[layer_name] = round((layer_size / layer_sum) * total)
            return final

        def process_tile(tile):
            if tile.z not in all_tile_sizes:
                all_tile_sizes[tile.z] = []

            level_tile_sizes = all_tile_sizes[tile.z]

            data = gzip.decompress(tile.data)
            size = sys.getsizeof(tile.data)
            vt = VectorTile(data)
            tile_all_layers_size = {}
            for layer in vt.layers:
                tile_layer_size = 0
                for feature in layer.features:
                    attr = feature.attributes.get()
                    geom = feature.get_geometry()
                    tile_layer_size += (sys.getsizeof(attr) + sys.getsizeof(geom))
                tile_all_layers_size[layer.name] = tile_layer_size
            tile_all_layers_size = normalize_tile_sizes(size, tile_all_layers_size)
            level_tile_sizes.append(TileItemSize(tile.x, tile.y, tile.z, size, tile_all_layers_size))

        with Pool(processes=multiprocessing.cpu_count()) as pool:
            pool.map(process_tile, tiles)

        result: List[LayerLevelSize] = []
        for z in sorted(all_tile_sizes.keys()):
            tiles = all_tile_sizes[z]
            total = sum([tile.size for tile in tiles])
            layer_sizes = {}
            for item in tiles:
                for layer_name, layer_size in item.layers.items():
                    if layer_name not in layer_sizes:
                        layer_sizes[layer_name] = 0
                    layer_sizes[layer_name] += layer_size
            result.append(LayerLevelSize(z, total, layer_sizes))

        return result

    def analyze(self) -> TilesetAnalysisResult:
        result = TilesetAnalysisResult()
        result.set_count_tiles_total(self.count_tiles())
        result.set_count_tiles_by_z(self.count_tiles_by_z())
        result.set_tiles_size_agg_sum_by_z(self.tiles_size_agg_sum_by_z())
        result.set_tiles_size_agg_min_by_z(self.tiles_size_agg_min_by_z())
        result.set_tiles_size_agg_max_by_z(self.tiles_size_agg_max_by_z())
        result.set_tiles_size_agg_avg_by_z(self.tiles_size_agg_avg_by_z())

        self._set_tilesize_z_dataframe()
        result.set_tiles_size_agg_50p_by_z(self.tiles_size_agg_50p_by_z())
        result.set_tiles_size_agg_85p_by_z(self.tiles_size_agg_85p_by_z())
        result.set_tiles_size_agg_90p_by_z(self.tiles_size_agg_90p_by_z())
        result.set_tiles_size_agg_95p_by_z(self.tiles_size_agg_95p_by_z())
        result.set_tiles_size_agg_99p_by_z(self.tiles_size_agg_99p_by_z())
        self._clear_tilesize_z_dataframe()

        result.set_tileset_info(self.tileset_info())

        result.set_tiles_size_agg_sum_by_z_layer(self.tiles_size_agg_sum_by_z_layer())

        return result




from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles
import uvicorn
import os
from pathlib import Path
from starlette.middleware.cors import CORSMiddleware
from starlette.requests import Request
from starlette.responses import RedirectResponse, FileResponse

UI_PATH = f'{Path(os.path.dirname(__file__)).parent}/static/ui'


def start_api(temp_folder):
    app = FastAPI()
    app.add_middleware(
        CORSMiddleware,
        allow_origins=["*"],
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )

    app.mount("/api", StaticFiles(directory=temp_folder), name="api")

    @app.get("/")
    async def index():
        return FileResponse(f'{UI_PATH}/index.html')

    app.mount("/static", StaticFiles(directory=f'{UI_PATH}/static'), name="ui")

    @app.get("/{file_name}.{file_path}")
    async def root_files(file_name: str, file_path: str):
        return FileResponse(f'{UI_PATH}/{file_name}.{file_path}')

    @app.get("/{path_name:path}")
    async def index_react_path(request: Request, path_name: str):
        return FileResponse(f'{UI_PATH}/index.html')
    
    uvicorn.run(app, host="0.0.0.0", port=8080)
    



import abc
from sqlite3 import Connection
from tileset_analyzer.data_source.mbtiles.mbtiles_source import MBTileSource


class TilesetSourceFactory:
    @staticmethod
    def get_tileset_source(src_path: str, scheme: str):
        try:
            if src_path.endswith('mbtiles'):
                return MBTileSource(src_path, scheme)
            
            raise AssertionError("Tileset Type is not valid.")
        except AssertionError as e:
            print(e)



from setuptools import setup, find_packages
from importlib.metadata import entry_points

CLASSIFIERS = [
    "Operating System :: OS Independent",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
]

setup(
    name='tileset_analyzer',
    version='0.0.37',
    url='https://github.com/geoyogesh/tileset_analyzer',
    license='MIT',
    author='Yogesh Dhanapal',
    author_email='geoyogesh@gmail.com',
    entry_points={"console_scripts": ["tileset_analyzer = tileset_analyzer.main:cli"]},
    description='Analyze vector Tileset',
    python_requires=">=3.9, <4",
    packages=find_packages(),
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    zip_safe=False,
    classifiers=CLASSIFIERS,
    include_package_data=True,
    install_requires=["fastapi", "uvicorn[standard]", "pandas", "protobuf"]
)



from tileset_analyzer.api.main_api import start_api
from tileset_analyzer.data_source.tile_source_factory import TilesetSourceFactory
from tileset_analyzer.utilities.moniter import timeit
from tileset_analyzer.utils.json_utils import write_json_file
import sys
import os
import argparse


def execute(src_path, scheme, temp_folder, actions):
    print('started...')
    print('src_path:', src_path)
    print('scheme:', scheme)
    print('temp_folder:', temp_folder)
    print('actions', actions)

    if 'process' in actions:
        process_job(scheme, src_path, temp_folder)

    if 'serve' in actions:
        print('Web UI started')
        start_api(temp_folder)
        print('Web UI stopped')

    print('completed')


@timeit
def process_job(scheme, src_path, temp_folder):
    print('processing started')
    data_source = TilesetSourceFactory.get_tileset_source(src_path, scheme)
    result = data_source.analyze()
    output_json = os.path.join(temp_folder, 'analysis_result.json')
    write_json_file(result.get_json(), output_json)
    print('processing completed')


def get_arg(param):
    source_index = sys.argv.index(param)
    val = sys.argv[source_index + 1]
    return val


def cli():
    parser = argparse.ArgumentParser(prog='tileset_analyzer')
    parser.add_argument('--source', help='source', required=True)
    parser.add_argument('--scheme', help='scheme', default='XYZ')
    parser.add_argument('--temp_folder', help='temp_folder', required=True)
    parser.add_argument('--actions', help='actions', default='process,serve')
    args = parser.parse_args()
    actions = args.actions.split(',')
    execute(args.source, args.scheme, args.temp_folder, actions)


'''
if __name__ == "__main__":
   cli()
'''



import abc
from sqlite3 import Connection
from typing import List

from tileset_analyzer.entities.layer_level_size import LayerLevelSize
from tileset_analyzer.entities.level_count import LevelCount
from tileset_analyzer.entities.level_size import LevelSize
from tileset_analyzer.entities.tileset_analysis_result import TilesetAnalysisResult
from tileset_analyzer.entities.tileset_info import TilesetInfo


class TileSource(abc.ABC):
    @abc.abstractmethod
    def __init__(self, src_path: str, scheme: str):
        pass

    @abc.abstractmethod
    def count_tiles(self) -> int:
        pass

    @abc.abstractmethod
    def count_tiles_by_z(self) -> List[LevelCount]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_sum_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_min_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_max_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_avg_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_50p_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_85p_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_90p_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_95p_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tiles_size_agg_99p_by_z(self) -> List[LevelSize]:
        pass

    @abc.abstractmethod
    def tileset_info(self) -> TilesetInfo:
        pass

    @abc.abstractmethod
    def tiles_size_agg_sum_by_z_layer(self) -> List[LayerLevelSize]:
        pass

    @abc.abstractmethod
    def analyze(self) -> TilesetAnalysisResult:
        pass
